@@ -664,6 +664,9 @@ FcConfigXdgConfigHome (void);
 FcPrivate FcChar8 *
 FcConfigXdgDataHome (void);
 
+FcPrivate FcStrSet *
+FcConfigXdgDataDirs (void);
+
 FcPrivate FcExpr *
 FcConfigAllocExpr (FcConfig *config);
 
@@ -1257,6 +1260,9 @@ FcIsFsMtimeBroken (const FcChar8 *dir);
 FcPrivate FcStrSet *
 FcStrSetCreateEx (unsigned int control);
 
+FcPrivate FcBool
+FcStrSetInsert (FcStrSet *set, const FcChar8 *s, int pos);
+
 FcPrivate FcBool
 FcStrSetAddLangs (FcStrSet *strs, const char *languages);
 
@@ -1368,10 +1374,6 @@ FcObjectLookupOtherTypeById (FcObject id);
 FcPrivate const FcObjectType *
 FcObjectLookupOtherTypeByName (const char *str);
 
-/* fcopentype.c */
-FcPrivate FcBool
-FcPatternAddFullname (FcPattern *pat);
-
 /* fchash.c */
 FcPrivate FcBool
 FcHashStrCopy (const void  *src,
